@@ -17,11 +17,8 @@
 #' 
 #' @import DBI
 #' @importFrom RSQLite SQLite
-#' @importMethodsFrom RSQLite dbConnect dbRemoveTable dbExistsTable 
-#' @importMethodsFrom RSQLite dbSendQuery dbDisconnect dbWriteTable
 #' @import data.table
 #' @importFrom RMySQL MySQL
-#' @importMethodsFrom RMySQL dbConnect dbWriteTable dbDisconnect 
 
 tcplAppend <- function(dat, tbl, db) {
   
@@ -58,6 +55,8 @@ tcplAppend <- function(dat, tbl, db) {
                                 paste(tmp_flds, collapse = ","),
                                 "FROM",
                                 tempTbl))
+    dbClearResult(status)
+    
     # Remove temporary table
     dbRemoveTable(dbcon, tempTbl)
     
